@@ -23,10 +23,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner",
-    "1.77.30",
-    __name__[0:-6],
-    "cdk-gitlab-runner@1.77.30.jsii.tgz",
+    "cdk-gitlab-runner", "1.90.0", __name__[0:-6], "cdk-gitlab-runner@1.90.0.jsii.tgz"
 )
 
 __all__ = [
